﻿using System.Collections.Generic;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;
using PokktSDK;
using PokktSDK.Delegates;
using PokktSDK.Utils;
using PokktSDK.Video;

namespace SampleApp
{
    public sealed partial class VideoCampaignPage : Page
    {
        private PokktConfig _config;

        public VideoCampaignPage()
        {
            InitializeComponent();

            NavigationCacheMode = NavigationCacheMode.Required;

            VideoCampaignDelegate.DownloadCompletedEvent += OnDownloadCompleted;
            VideoCampaignDelegate.DownloadFailedEvent += OnDownloadFailed;
            VideoCampaignDelegate.VideoDisplayedEvent += OnVideoDisplayed;
            VideoCampaignDelegate.VideoCompletedEvent += OnVideoCompleted;
            VideoCampaignDelegate.VideoClosedEvent += OnVideoClosed;
            VideoCampaignDelegate.VideoSkippedEvent += OnVideoSkipped;
            VideoCampaignDelegate.VideoGratifiedEvent += OnVideoGratified;
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            Dictionary<string, object> parameters = e.Parameter as Dictionary<string, object>;
            if (parameters == null)
                return;

            _config = (PokktConfig)parameters["config"];

            // enable buttons if video is downloaded
            if (PokktManager.IsVideoAvailable())
            {
                OnDownloadCompleted(PokktManager.GetVideoVc());
            }
            else
            {
                CacheVideo.IsEnabled = !_config.AutoCacheVideo;
                if (CacheVideo.IsEnabled)
                    ButtonStatusLabel.Text = "cache video to enable playback!";
            }
        }

        private void OnClickCacheVideo(object sender, RoutedEventArgs e)
        {
            CacheVideo.IsEnabled = false;
            PokktManager.CacheVideoCampaign(_config);
            ButtonStatusLabel.Text = "video is downloading...";
        }

        private void OnClickPlayVideoWithIncent(object sender, RoutedEventArgs e)
        {
            _config.Incentivised = true;

            PokktManager.PlayVideo(_config);
        }

        private void OnClickPlayVideoNonIncent(object sender, RoutedEventArgs e)
        {
            _config.Incentivised = false;

            PokktManager.PlayVideo(_config);
        }

        private void OnDownloadCompleted(float result)
        {
            Logger.Log("video is downloaded, video vc is {0}", result);
            ButtonStatusLabel.Text = "video is downloaded!";

            CacheVideo.IsEnabled = false;
            PlayVideoIncent.IsEnabled = true;
            PlayVideoNonIncent.IsEnabled = true;
        }

        private void OnDownloadFailed(string message)
        {
            ButtonStatusLabel.Text = "video downloaded failed! message: " + message;
            PointsEarned.Text = "Video VC: " + "n/a";
            Logger.Log(ButtonStatusLabel.Text);

            CacheVideo.IsEnabled = !_config.AutoCacheVideo;
            PlayVideoIncent.IsEnabled = false;
            PlayVideoNonIncent.IsEnabled = false;
        }

        private void OnVideoDisplayed()
        {
            ButtonStatusLabel.Text = "video is playing...";
            Logger.Log(ButtonStatusLabel.Text);

            PlayVideoIncent.IsEnabled = false;
            PlayVideoNonIncent.IsEnabled = false;
        }

        private void OnVideoCompleted()
        {
            ButtonStatusLabel.Text = "video playback completed!";
            Logger.Log(ButtonStatusLabel.Text);
        }

        private void OnVideoClosed(bool backPress)
        {
            ButtonStatusLabel.Text = "video closed!";
            Logger.Log(ButtonStatusLabel.Text);

            CacheVideo.IsEnabled = !_config.AutoCacheVideo;
        }

        private void OnVideoSkipped()
        {
            ButtonStatusLabel.Text = "video playback skipped!";
            Logger.Log(ButtonStatusLabel.Text);
        }

        private void OnVideoGratified(VideoResponse response)
        {
            string coins = response.Coins;
            PointsEarned.Text = "Video VC: " + coins;
            ButtonStatusLabel.Text = "gratifed user with: " + coins;
            Logger.Log(ButtonStatusLabel.Text);
        }
    }
}
